@@ -1,5 +1,6 @@
 import logging
-from robit.worker import Worker
+from robit.worker.worker import Worker
+from robit.monitor.monitor import Monitor
 
 FORMAT = '[%(asctime)-15s] %(message)s'
 logging.basicConfig(format=FORMAT)
